
# q-expansion of newform 1728.2.r.f, downloaded from the LMFDB on 09 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1728
weight = 2
poly_data = [36, 144, 288, 384, 304, 96, 0, -24, -16, 0, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-96192, -26082, -44964, -51252, -27262, 5062, 3300, 1747, 1148, -650, 300, -275], 51972], [[275832, 708624, 1654212, 921960, 209952, -31862, -131336, -22648, 8976, -10784, 7708, 839], 103944], [[15984, 49284, -132080, 98118, 57708, 11380, 14442, -13990, -2220, 2887, -2392, 962], 51972], [[-5172, -12468, -22776, -27758, -10408, -1364, 1416, 1866, 32, -53, 90, -118], 1704], [[133704, 364968, 348980, 562962, 219348, 17238, -7530, -44568, -2808, 4065, -3602, 2793], 34648], [[268416, 645714, 1177668, 1432764, 530594, 65542, -72588, -93803, -2632, 3454, -4740, 6049], 51972], [[105120, 282372, 400856, 420176, 151968, 12648, -24587, -26378, -684, 840, -1054, 1688], 12993], [[-1037028, -1622652, -2984520, -3664246, -1340808, -234336, 188112, 267718, -11340, -681, 10866, -15676], 103944], [[-1369008, -3656232, -5685648, -5346606, -1841148, -103124, 348166, 317744, 1848, -3611, 7150, -19630], 103944], [[4860, 29640, 53952, 65498, 26820, 2664, -3408, -4304, -192, 159, -222, 284], 1464], [[-462528, -1237836, -1805344, -1820914, -637476, -40656, 108978, 110866, 1476, -2205, 3388, -6916], 34648]]

hecke_ring_character_values = [[703, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [325, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1217, [0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 1], [0, 0, 0, 0, 0, -1, 0, 0, 0, -1, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0], [0, 0, -1, 1, 0, -1, 0, -2, 0, -2, 0, -2], [-1, 1, 0, 0, 1, 0, -1, 0, 0, 0, 0, 0], [0, 0, 1, -1, 0, 1, 0, 2, 0, 0, 0, 0], [2, 0, 0, 0, 2, 0, 0, 0, 1, 0, -1, 0], [0, 0, 0, 0, 3, 0, 1, 0, 0, 0, 0, 0], [0, 0, 1, -2, 0, 2, 0, 2, 0, 2, 0, 1], [0, 0, -1, 1, 0, 2, 0, 1, 0, -2, 0, 1], [-2, -1, 0, 0, -4, 0, -2, 0, 0, 0, 0, 0], [0, 0, 1, 3, 0, -1, 0, 0, 0, 1, 0, -1], [1, 1, 0, 0, -1, 0, -1, 0, 0, 0, 0, 0], [0, 0, 1, 2, 0, -1, 0, 0, 0, 2, 0, -2], [0, 0, -1, -4, 0, -1, 0, 2, 0, -2, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0], [0, 0, 0, -1, 0, 1, 0, -1, 0, -1, 0, 1], [0, 0, 1, -3, 0, 2, 0, 3, 0, 2, 0, 1], [4, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0], [-1, 3, 0, 0, -1, 0, 3, 0, 0, 0, 0, 0], [-5, -1, 0, 0, 2, 0, 1, 0, -3, 0, 0, 0], [0, 0, 1, 2, 0, 1, 0, -4, 0, -1, 0, -1], [0, 0, -2, 0, 0, 0, 0, -6, 0, -2, 0, -2], [6, -1, 0, 0, 8, 0, -2, 0, 2, 0, -2, 0], [2, 0, 0, 0, 6, 0, -3, 0, 2, 0, -1, 0], [0, 0, 2, 4, 0, -2, 0, -2, 0, 0, 0, -2], [0, 0, 1, -3, 0, -1, 0, 0, 0, -1, 0, 1], [-13, 2, 0, 0, -12, 0, 2, 0, -1, 0, 2, 0], [0, 0, 1, -2, 0, -1, 0, 0, 0, -1, 0, 1], [6, 2, 0, 0, 3, 0, 1, 0, 0, 0, 0, 0], [0, 0, -2, 2, 0, 1, 0, 2, 0, -1, 0, -1], [8, 2, 0, 0, 4, 0, 1, 0, 0, 0, 1, 0], [0, 0, -4, 0, 0, -2, 0, 2, 0, -2, 0, -4], [0, 0, 3, 2, 0, 3, 0, -4, 0, 3, 0, 3], [-7, 0, 0, 0, 7, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 3, 0, 0, 0, 0], [-2, 0, 0, 0, -2, 0, 0, 0, -1, 0, 1, 0], [0, 0, 1, 2, 0, -2, 0, 2, 0, 2, 0, -1], [4, 0, 0, 0, -1, 0, -3, 0, 4, 0, -2, 0], [0, -1, 0, 0, -6, 0, -2, 0, 3, 0, -3, 0], [0, 0, -1, -8, 0, 3, 0, 4, 0, 2, 0, 1], [0, 0, -1, -1, 0, 1, 0, 0, 0, -2, 0, 2], [0, 0, 3, -2, 0, -2, 0, -2, 0, 2, 0, 1], [0, 0, 0, 3, 0, 1, 0, -3, 0, 1, 0, 1], [2, -4, 0, 0, 1, 0, -2, 0, 0, 0, -2, 0], [-6, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 5, 0, -1, 0, -10, 0, -2, 0, -2], [9, 0, 0, 0, 7, 0, 0, 0, 2, 0, -4, 0], [0, 0, 0, 0, 0, -2, 0, -6, 0, 2, 0, 0], [-2, 0, 0, 0, 12, 0, -1, 0, -2, 0, 1, 0], [0, 0, -4, 3, 0, -1, 0, 3, 0, 1, 0, -5], [-6, 2, 0, 0, -6, 0, 4, 0, -3, 0, 3, 0], [0, 0, -4, 2, 0, 2, 0, -1, 0, -2, 0, 4], [1, -1, 0, 0, -2, 0, 1, 0, -1, 0, 0, 0], [-9, 0, 0, 0, -6, 0, 0, 0, -3, 0, 6, 0], [0, 0, -3, -2, 0, 3, 0, 0, 0, 3, 0, -3], [16, 2, 0, 0, 8, 0, 1, 0, 0, 0, 3, 0], [0, 0, 4, 0, 0, 2, 0, -2, 0, 2, 0, 4], [0, 0, -3, 2, 0, -3, 0, -4, 0, 0, 0, 0], [-15, 0, 0, 0, -13, 0, 0, 0, -2, 0, 4, 0], [-3, 0, 0, 0, 6, 0, 0, 0, 3, 0, 0, 0], [0, 0, -2, 5, 0, -7, 0, -5, 0, -7, 0, -5], [-2, 0, 0, 0, -2, 0, 3, 0, -2, 0, 1, 0], [0, 0, 1, 3, 0, -1, 0, 0, 0, 4, 0, -4], [-3, -3, 0, 0, 2, 0, 3, 0, -1, 0, 0, 0], [-17, -2, 0, 0, -18, 0, -2, 0, 1, 0, -2, 0], [0, 0, 4, 2, 0, -2, 0, -1, 0, 2, 0, -4], [0, 0, -4, 2, 0, -1, 0, 2, 0, 1, 0, -5], [6, -2, 0, 0, 3, 0, -1, 0, 0, 0, 2, 0], [0, 0, -7, 0, 0, -5, 0, -2, 0, -2, 0, -7], [0, 0, -1, 2, 0, -1, 0, -4, 0, 1, 0, 1], [-5, 1, 0, 0, 8, 0, -1, 0, 3, 0, 0, 0], [6, 1, 0, 0, 16, 0, 2, 0, -2, 0, 2, 0], [-2, 0, 0, 0, -18, 0, -2, 0, -2, 0, 1, 0], [-4, 0, 0, 0, -7, 0, 0, 0, -4, 0, 2, 0], [0, 0, -1, 0, 0, 1, 0, 0, 0, 4, 0, -4], [-3, -3, 0, 0, -1, 0, 3, 0, -4, 0, 0, 0], [0, 0, -2, 2, 0, 4, 0, -1, 0, 2, 0, 2], [0, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0], [0, 0, -2, -6, 0, 1, 0, -6, 0, -1, 0, -1], [0, 0, 1, -9, 0, 6, 0, 9, 0, 6, 0, 5], [-4, 2, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0], [-13, -3, 0, 0, -11, 0, -3, 0, -2, 0, 4, 0], [3, -3, 0, 0, -3, 0, 3, 0, 0, 0, 0, 0], [0, 0, -1, -4, 0, -1, 0, 8, 0, 0, 0, 0], [0, 0, -4, 0, 0, 0, 0, 3, 0, -4, 0, -4], [0, 0, 6, 3, 0, -3, 0, 3, 0, 3, 0, 3], [0, 0, 4, 14, 0, -6, 0, -7, 0, -2, 0, -4], [0, 0, -7, 3, 0, 7, 0, 0, 0, -7, 0, 7], [0, 0, -5, 5, 0, 5, 0, 0, 0, -1, 0, 1], [0, 0, 1, -8, 0, 1, 0, 4, 0, 2, 0, -1], [-2, 2, 0, 0, -1, 0, 1, 0, 0, 0, 0, 0], [-6, -5, 0, 0, 0, 0, 0, 0, -3, 0, -3, 0], [0, 0, -3, 0, 0, 3, 0, -8, 0, -6, 0, -3], [8, -3, 0, 0, 14, 0, -6, 0, 1, 0, -1, 0], [0, 0, -4, -4, 0, 1, 0, 4, 0, 1, 0, 5], [6, -3, 0, 0, 0, 0, -6, 0, 6, 0, -6, 0], [0, 0, -1, -12, 0, 1, 0, 0, 0, -4, 0, 4], [-9, -2, 0, 0, -9, 0, -2, 0, 0, 0, 0, 0], [0, 0, 1, 4, 0, -1, 0, 0, 0, 2, 0, -2], [12, 3, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0], [0, 0, 1, -6, 0, 4, 0, 6, 0, 4, 0, 3], [4, -3, 0, 0, 0, 0, 0, 0, -2, 0, -2, 0], [0, 0, -5, -2, 0, -5, 0, 4, 0, -7, 0, -7], [5, 0, 0, 0, 4, 0, 0, 0, 1, 0, -2, 0], [0, 0, -1, 3, 0, -1, 0, -6, 0, -7, 0, -7], [10, 1, 0, 0, 20, 0, 2, 0, 0, 0, 0, 0], [4, 0, 0, 0, -15, 0, -1, 0, 4, 0, -2, 0], [0, 0, 2, 2, 0, -5, 0, -2, 0, -5, 0, -7], [0, 0, -2, -6, 0, 0, 0, 3, 0, -2, 0, 2], [-5, 4, 0, 0, -3, 0, 4, 0, -2, 0, 4, 0], [0, 0, 5, 4, 0, -5, 0, 0, 0, 4, 0, -4], [0, 0, -2, 2, 0, -8, 0, -1, 0, -10, 0, 2], [-6, 8, 0, 0, -3, 0, 4, 0, 0, 0, 0, 0], [0, 0, 0, 15, 0, -3, 0, -15, 0, -3, 0, -3], [16, -6, 0, 0, 8, 0, -3, 0, 0, 0, -3, 0], [-9, 3, 0, 0, -7, 0, 3, 0, -2, 0, 4, 0], [11, 1, 0, 0, -14, 0, -1, 0, -3, 0, 0, 0], [0, 0, -8, 0, 0, -2, 0, -6, 0, -6, 0, -8], [0, 0, 3, -4, 0, 0, 0, 4, 0, 0, 0, -3], [18, -4, 0, 0, 30, 0, -8, 0, 3, 0, -3, 0], [19, 0, 0, 0, -15, 0, 0, 0, 4, 0, 0, 0], [0, 0, 2, 12, 0, -10, 0, -6, 0, -8, 0, -2], [0, 0, 10, 3, 0, -5, 0, 3, 0, 5, 0, 5], [-2, -6, 0, 0, -1, 0, -3, 0, 0, 0, -10, 0], [0, 0, 1, 0, 0, -1, 0, -14, 0, 2, 0, 1], [0, 0, 3, 2, 0, 3, 0, -4, 0, -3, 0, -3], [0, 0, 1, 6, 0, 1, 0, -12, 0, 3, 0, 3], [8, 4, 0, 0, 16, 0, 8, 0, 0, 0, 0, 0], [2, 0, 0, 0, 0, 0, -6, 0, 2, 0, -1, 0], [8, 0, 0, 0, -1, 0, 0, 0, 8, 0, -4, 0], [-2, -2, 0, 0, 2, 0, -4, 0, -3, 0, 3, 0], [0, 0, 3, -11, 0, -3, 0, 0, 0, 3, 0, -3], [2, 2, 0, 0, 1, 0, 1, 0, 0, 0, -6, 0], [-20, 4, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0], [0, 0, 4, 0, 0, 8, 0, 1, 0, -4, 0, 4], [11, 1, 0, 0, -11, 0, -1, 0, 0, 0, 0, 0], [0, 0, 5, -5, 0, 5, 0, 10, 0, 2, 0, 2], [0, 0, 2, 0, 0, -2, 0, -3, 0, 4, 0, 2], [10, -3, 0, 0, 0, 0, -6, 0, 10, 0, -10, 0], [0, 0, -9, -5, 0, 6, 0, -5, 0, -6, 0, -3], [-19, -1, 0, 0, 19, 0, 1, 0, 0, 0, 0, 0], [17, 3, 0, 0, 15, 0, 3, 0, 2, 0, -4, 0], [0, 0, -1, 5, 0, 1, 0, 0, 0, 10, 0, -10], [0, 0, 6, 14, 0, -12, 0, -7, 0, -6, 0, -6], [-14, 14, 0, 0, -7, 0, 7, 0, 0, 0, 4, 0], [-32, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0], [0, 0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0], [0, 0, 1, -6, 0, 1, 0, 12, 0, -4, 0, -4], [0, 0, 3, -14, 0, 0, 0, 14, 0, 0, 0, -3], [0, 0, -8, -8, 0, 1, 0, -8, 0, -1, 0, -7], [0, 0, 6, 6, 0, 0, 0, -3, 0, 6, 0, -6], [1, -3, 0, 0, -3, 0, -3, 0, 4, 0, -8, 0], [-24, 3, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0], [-34, 0, 0, 0, -17, 0, 0, 0, 0, 0, 6, 0], [0, 0, 0, 9, 0, 1, 0, -9, 0, 1, 0, 1], [12, 2, 0, 0, 0, 0, 0, 0, -3, 0, -3, 0], [0, 0, 3, 4, 0, 3, 0, -8, 0, 0, 0, 0], [0, 0, -5, 0, 0, 5, 0, 0, 0, -10, 0, -5], [6, 0, 0, 0, -12, 0, 1, 0, 6, 0, -3, 0], [0, 0, 4, 6, 0, 1, 0, 6, 0, -1, 0, 5], [0, 0, -2, 2, 0, -8, 0, -1, 0, -10, 0, 2], [-3, 5, 0, 0, 6, 0, -5, 0, 3, 0, 0, 0], [16, -9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -3, 0], [0, 0, 3, 0, 0, -2, 0, 0, 0, -2, 0, -5], [42, -2, 0, 0, 21, 0, -1, 0, 0, 0, 0, 0], [0, 0, 1, -8, 0, 1, 0, 16, 0, 2, 0, 2], [27, 3, 0, 0, 23, 0, 3, 0, 4, 0, -8, 0], [0, 0, 11, 7, 0, 11, 0, -14, 0, 5, 0, 5], [-2, 0, 0, 0, 0, 0, 3, 0, -2, 0, 1, 0], [0, 0, -1, -4, 0, 4, 0, 4, 0, 4, 0, 5], [-2, 1, 0, 0, 8, 0, 2, 0, -6, 0, 6, 0], [0, 0, 2, -16, 0, -2, 0, 8, 0, 0, 0, -2], [1, 5, 0, 0, 4, 0, -5, 0, 5, 0, 0, 0], [0, 0, -3, -6, 0, -4, 0, -6, 0, 4, 0, -7], [0, 0, 3, 6, 0, 2, 0, -6, 0, 2, 0, -1], [6, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0], [-12, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 5, 3, 0, 5, 0, -6, 0, 7, 0, 7], [-3, 0, 0, 0, -6, 0, 0, 0, -9, 0, 0, 0], [-8, 4, 0, 0, -16, 0, 8, 0, 0, 0, 0, 0], [0, 0, -5, 10, 0, -16, 0, -10, 0, -16, 0, -11], [-6, 0, 0, 0, 16, 0, 3, 0, -6, 0, 3, 0], [0, 0, -8, 16, 0, 4, 0, -8, 0, -4, 0, 8], [8, -6, 0, 0, 0, 0, 0, 0, -3, 0, -3, 0], [0, 0, -4, 6, 0, -13, 0, -6, 0, -13, 0, -9], [0, 0, -16, 0, 0, -2, 0, -20, 0, -14, 0, -16], [11, -5, 0, 0, -14, 0, 5, 0, -3, 0, 0, 0], [0, 0, 6, 0, 0, -2, 0, 9, 0, 8, 0, 6], [6, 0, 0, 0, -24, 0, -7, 0, 6, 0, -3, 0], [0, 0, 0, 0, 13, 0, -9, 0, 0, 0, 0, 0], [-7, -3, 0, 0, 12, 0, 3, 0, 5, 0, 0, 0], [-23, 5, 0, 0, -18, 0, 5, 0, -5, 0, 10, 0], [0, 0, -4, 8, 0, -4, 0, -4, 0, -8, 0, 4], [-4, -6, 0, 0, -2, 0, -3, 0, 0, 0, -3, 0], [0, 0, -5, 7, 0, 0, 0, 7, 0, 0, 0, -5], [48, 2, 0, 0, 24, 0, 1, 0, 0, 0, 1, 0], [-5, 9, 0, 0, 2, 0, 9, 0, -7, 0, 14, 0], [0, 0, -6, 0, 0, -2, 0, -9, 0, -4, 0, -6], [-2, 4, 0, 0, 2, 0, 8, 0, -3, 0, 3, 0], [0, 0, -4, -14, 0, 6, 0, 7, 0, 2, 0, 4], [0, 0, 3, -18, 0, -3, 0, 0, 0, 1, 0, -1], [15, -4, 0, 0, 15, 0, -4, 0, 0, 0, 0, 0], [0, 0, 5, 14, 0, -5, 0, 0, 0, -5, 0, 5], [-8, -3, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0], [-32, 0, 0, 0, -16, 0, 0, 0, 0, 0, 9, 0], [0, 0, -1, -11, 0, -4, 0, -11, 0, 4, 0, -5], [0, 0, 10, 3, 0, 11, 0, -3, 0, 11, 0, 1], [0, 0, -5, -12, 0, -5, 0, 24, 0, -1, 0, -1], [-13, 9, 0, 0, -14, 0, 9, 0, 1, 0, -2, 0], [0, 0, -3, -11, 0, -3, 0, 22, 0, -4, 0, -4], [11, -4, 0, 0, 12, 0, -4, 0, -1, 0, 2, 0], [0, 0, 10, 6, 0, -8, 0, -3, 0, 2, 0, -10], [-4, 0, 0, 0, -2, 0, 0, 0, 0, 0, 3, 0], [-48, -4, 0, 0, -24, 0, -2, 0, 0, 0, 7, 0], [0, 0, -1, 9, 0, -1, 0, -18, 0, 1, 0, 1], [-2, 0, 0, 0, 18, 0, 8, 0, -2, 0, 1, 0], [0, 0, 2, 14, 0, 12, 0, -7, 0, 14, 0, -2], [0, 0, 1, 3, 0, -1, 0, 0, 0, 1, 0, -1], [-7, 1, 0, 0, 12, 0, -1, 0, 5, 0, 0, 0], [-1, 6, 0, 0, -3, 0, 6, 0, 2, 0, -4, 0], [0, 0, -2, -6, 0, 4, 0, 3, 0, 2, 0, 2], [0, 0, 12, 6, 0, -5, 0, 6, 0, 5, 0, 7], [0, 0, -10, 0, 0, 1, 0, 0, 0, 1, 0, 11], [-8, -2, 0, 0, -4, 0, -1, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 6, 0, 8, 0, -6, 0, 0], [0, 0, -11, -5, 0, -11, 0, 10, 0, -2, 0, -2], [0, 0, 0, 0, 21, 0, -14, 0, 0, 0, 0, 0], [0, 0, 4, -8, 0, 5, 0, 8, 0, 5, 0, 1], [0, 0, -1, 8, 0, -4, 0, 8, 0, 4, 0, -5], [-2, 0, 0, 0, -8, 0, 0, 0, -2, 0, 1, 0], [14, 0, 0, 0, 10, 0, 0, 0, 9, 0, -9, 0], [0, 0, 9, 3, 0, -9, 0, 0, 0, 7, 0, -7], [0, 0, 6, 0, 0, 6, 0, 0, 0, 12, 0, -6], [0, 0, -1, -6, 0, 6, 0, 6, 0, 6, 0, 7], [0, 0, -12, 0, 0, 0, 0, -1, 0, -12, 0, -12], [0, 0, -5, -7, 0, -5, 0, 14, 0, -1, 0, -1], [-22, 5, 0, 0, -44, 0, 10, 0, 0, 0, 0, 0], [-6, 0, 0, 0, -12, 0, 4, 0, -6, 0, 3, 0], [0, 0, -7, -8, 0, 2, 0, -8, 0, -2, 0, -5], [0, 0, 2, 8, 0, 10, 0, -4, 0, 12, 0, -2], [0, 0, 1, -3, 0, -1, 0, 0, 0, -8, 0, 8], [0, 0, -3, -2, 0, 3, 0, 0, 0, -12, 0, 12], [0, 0, 2, 6, 0, 8, 0, -3, 0, 10, 0, -2], [-36, -4, 0, 0, -18, 0, -2, 0, 0, 0, -3, 0], [8, -8, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0], [0, 0, 3, 11, 0, 3, 0, -22, 0, 0, 0, 0], [-7, -12, 0, 0, -13, 0, -12, 0, 6, 0, -12, 0], [-15, -2, 0, 0, 15, 0, 2, 0, 0, 0, 0, 0], [0, 0, -5, 0, 0, -3, 0, 18, 0, -2, 0, -5], [-14, 3, 0, 0, -4, 0, 6, 0, -12, 0, 12, 0], [0, 0, 6, 23, 0, 9, 0, -23, 0, 9, 0, 3], [28, -3, 0, 0, 38, 0, -6, 0, 9, 0, -9, 0], [48, -3, 0, 0, 0, 0, 0, 0, -2, 0, -2, 0], [0, 0, 2, 5, 0, 3, 0, 5, 0, -3, 0, 5], [0, 0, 9, 9, 0, 2, 0, -9, 0, 2, 0, -7], [32, -10, 0, 0, 16, 0, -5, 0, 0, 0, -3, 0], [10, 2, 0, 0, 22, 0, 4, 0, -1, 0, 1, 0], [8, 0, 0, 0, 39, 0, -3, 0, 8, 0, -4, 0], [0, 0, -8, -14, 0, -7, 0, 14, 0, -7, 0, 1], [22, 2, 0, 0, 26, 0, 4, 0, 9, 0, -9, 0], [-27, -1, 0, 0, -30, 0, -1, 0, 3, 0, -6, 0], [0, 0, -11, 8, 0, 11, 0, 0, 0, -4, 0, 4], [34, 6, 0, 0, 17, 0, 3, 0, 0, 0, 6, 0], [2, -6, 0, 0, 1, 0, -3, 0, 0, 0, -4, 0], [0, 0, 4, 0, 0, 8, 0, -11, 0, -4, 0, 4], [25, 0, 0, 0, 23, 0, 0, 0, 2, 0, -4, 0], [0, 0, 9, -14, 0, 9, 0, 28, 0, 15, 0, 15], [-8, 0, 0, 0, -19, 0, 3, 0, -8, 0, 4, 0], [0, 0, 0, 8, 0, 0, 0, -4, 0, 0, 0, 0], [0, 0, -1, -12, 0, 1, 0, 0, 0, 7, 0, -7], [13, -1, 0, 0, -23, 0, 1, 0, -10, 0, 0, 0], [12, -6, 0, 0, 0, 0, 0, 0, -5, 0, -5, 0], [0, 0, -6, 21, 0, -13, 0, -21, 0, -13, 0, -7], [0, 0, -1, 6, 0, -1, 0, -12, 0, 1, 0, 1], [0, 0, -9, 7, 0, -9, 0, -14, 0, -7, 0, -7], [0, 0, 0, 6, 0, -3, 0, 6, 0, 3, 0, -3], [-13, 0, 0, 0, 13, 0, 0, 0, 0, 0, 0, 0], [0, 0, 1, 8, 0, -1, 0, 0, 0, 5, 0, -5], [0, 0, 7, 0, 0, -5, 0, 0, 0, 2, 0, -7], [40, 0, 0, 0, 0, 0, 0, 0, -1, 0, -1, 0], [4, 10, 0, 0, 2, 0, 5, 0, 0, 0, 9, 0], [0, 0, -9, 4, 0, 6, 0, 4, 0, -6, 0, -3], [34, 4, 0, 0, 0, 0, 0, 0, 4, 0, 4, 0], [7, -5, 0, 0, -13, 0, 5, 0, -6, 0, 0, 0], [0, 0, -1, 0, 0, -3, 0, -6, 0, 2, 0, -1], [4, 0, 0, 0, 39, 0, 4, 0, 4, 0, -2, 0], [0, 0, -7, -15, 0, 7, 0, 0, 0, -6, 0, 6], [-33, 2, 0, 0, 33, 0, -2, 0, 0, 0, 0, 0], [12, -2, 0, 0, 6, 0, -1, 0, 0, 0, -3, 0], [0, 0, -8, -13, 0, 5, 0, -13, 0, -5, 0, -3], [-39, 0, 0, 0, 42, 0, 0, 0, 3, 0, 0, 0], [0, 0, 16, 0, 0, 2, 0, 6, 0, 14, 0, 16], [0, 0, 1, 2, 0, 14, 0, -2, 0, 14, 0, 13], [6, 0, 0, 0, 22, 0, 9, 0, 6, 0, -3, 0], [22, 4, 0, 0, 26, 0, 8, 0, 9, 0, -9, 0], [0, 0, 4, 28, 0, -12, 0, -14, 0, -8, 0, -4]]
